@@ -17,7 +17,7 @@ use std::sync::Arc;
 use std::sync::Mutex;
 use std::time::Instant;
 
-use morsels_common::tokenize::Tokenizer;
+use morsels_common::tokenize::IndexerTokenizer;
 use morsels_common::{MorselsLanguageConfig, BITMAP_DOCINFO_DICT_TABLE_FILE, BitmapDocinfoDicttableReader};
 use morsels_lang_ascii::ascii;
 use morsels_lang_latin::latin;
@@ -52,7 +52,7 @@ fn get_default_num_threads() -> usize {
 }
 
 fn get_default_pl_limit() -> u32 {
-    16383
+    5242880
 }
 
 fn get_default_num_docs_per_block() -> u32 {
@@ -60,7 +60,7 @@ fn get_default_num_docs_per_block() -> u32 {
 }
 
 fn get_default_pl_cache_threshold() -> u32 {
-    1048576
+    0
 }
 
 fn get_default_exclude_patterns() -> Vec<String> {
@@ -428,7 +428,7 @@ impl Indexer {
         indexer
     }
 
-    fn resolve_tokenizer(lang_config: &MorselsLanguageConfig) -> Arc<dyn Tokenizer + Send + Sync> {
+    fn resolve_tokenizer(lang_config: &MorselsLanguageConfig) -> Arc<dyn IndexerTokenizer + Send + Sync> {
         match lang_config.lang.as_str() {
             "ascii" => {
                 if let Some(options) = lang_config.options.as_ref() {
